@@ -1,7 +1,7 @@
 __all__ = ["core", "manifold", "manifold_np", "manifold_torch"]
 __author__ = 'Nachuan Xiao, Xiaoyin Hu, Xin Liu, and Kim-Chuan Toh'
 
-PRINT_STATUS = False
+_PRINT_STATUS = False
 
 from . import manifold_np,  manifold
 from .core import problem, backbone_autograd
@@ -12,7 +12,7 @@ try:
     from . import manifold_torch
     from . import nn
 except ImportError:
-    if PRINT_STATUS:
+    if _PRINT_STATUS:
         print('Warning: Cannot import PyTorch-related components, including `cdopt.manifold_torch` and `cdopt.nn`. Please check whether PyTorch is correctly installed.')
 
 
@@ -21,5 +21,5 @@ try:
     from .core  import backbone_jax
     from . import manifold_jax
 except ImportError:
-    if PRINT_STATUS:
+    if _PRINT_STATUS:
         print('Warning: Cannot import JAX-related components. Please check whether JAX is correctly installed.')
