@@ -19,7 +19,7 @@ class euclidean_torch(basic_manifold_torch):
         
         
 
-        super().__init__('Oblique',var_shape, (1,),   device= self.device ,dtype= self.dtype)
+        super().__init__('eclidean',var_shape, (1,),   device= self.device ,dtype= self.dtype)
 
         self._parameters['zeroX'] = torch.zeros(self.var_shape).to(device = self.device, dtype = self.dtype)
         self._parameters['zero_scalar'] = torch.zeros((1,)).to(device = self.device, dtype = self.dtype)
@@ -44,7 +44,7 @@ class euclidean_torch(basic_manifold_torch):
 
     def JA_transpose(self,X,G):
         # JA is self-adjoint
-        return self.JA(X,G)
+        return G
 
     def hessA(self, X, gradf, D):
         return self.zeroX
@@ -62,7 +62,7 @@ class euclidean_torch(basic_manifold_torch):
 
 
     def hess_feas(self, X, D):
-        return 4*X @ self.Phi( X.T @ D ) + 2*D @ self.C(X)
+        return self.zeroX
 
     
 
